searchData={"items":[{"type":"module","title":"SocketReply","doc":"`SocketReply` lets you pipe the reply in a Phoenix LiveView.\nJust write `socket |> assigns |> reply` in `mount` and `handle_*` functions insted of dealing with tuples.","ref":"SocketReply.html"},{"type":"function","title":"SocketReply.reply/2","doc":"Transforms a piped reply into a response tuple.","ref":"SocketReply.html#reply/2"},{"type":"function","title":"Examples - SocketReply.reply/2","doc":"def mount(_params, _session, socket) do\n      socket\n      |> assign(:posts, Blog.list_posts())\n      |> assign(:post, nil)\n      |> reply(:ok)\n    end","ref":"SocketReply.html#reply/2-examples"},{"type":"function","title":"SocketReply.reply/3","doc":"Transforms a piped reply with data into a response tuple.\nWorks with maps and keyword lists.","ref":"SocketReply.html#reply/3"},{"type":"function","title":"Examples - SocketReply.reply/3","doc":"def handle_event(\"update\", params, socket) do\n      {:ok, post} = Blog.get_post!(id)\n\n      socket\n      |> assign(:post, Blog.get_post!(id))\n      |> reply(:reply, %{last_update: post.updated_at}})\n    end","ref":"SocketReply.html#reply/3-examples"},{"type":"extras","title":"SocketReply for Phoenix LiveView","doc":"# SocketReply for Phoenix LiveView\n\n**Pipe the response of LiveView functions**","ref":"readme.html"},{"type":"extras","title":"Installation - SocketReply for Phoenix LiveView","doc":"Simply add `socket_reply` to your list of dependencies in your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:socket_reply, \"~> 0.1.0\"}\n  ]\nend\n```\n\nand import it in your Web-Module `lib/my_app_web.ex` inside `html_helpers`.\n\n```elixir\ndefp html_helpers do\n  quote do\n    # HTML escaping functionality\n    import Phoenix.HTML\n\n    # SocketReply goes here\n    import SocketReply\n\n    ...\n```\n\nDocumentation can be found at https://hexdocs.pm/socket_reply","ref":"readme.html#installation"},{"type":"extras","title":"Usage - SocketReply for Phoenix LiveView","doc":"You can now use `reply/2` to pipe the response in `mount` and `handle_*` all the way down.\n\n```elixir\ndef mount(_params, _session, socket) do\n  socket\n  |> assign(:posts, Blog.list_posts())\n  |> assign(:post, nil)\n  |> reply(:ok)\nend\n\ndef handle_params(%{\"id\" => id}, _, socket) do\n  socket\n  |> assign(:post, Blog.get_post!(id))\n  |> reply(:noreply)\nend\n```\n\nand if you want to reply with data, it works as well using `reply/3`\n\n```elixir\ndef handle_event(\"update\", params, socket) do\n  {:ok, post} = Blog.get_post!(id)\n\n  socket\n  |> assign(:post, Blog.get_post!(id))\n  |> reply(:reply, %{last_update: post.updated_at}})\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"MIT License","doc":"# MIT License\n\nCopyright (c) 2024 Robert Röske\n\nPermission is hereby granted, free of charge, to any person obtaining\na copy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be\nincluded in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND,\nEXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND\nNONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE\nLIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION\nOF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION\nWITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}